Evaluation Methods
======================

.. automodule:: cornac.eval_methods

Base Method
-----------------------------------------------
.. automodule:: cornac.eval_methods.base_method
   :members:
   
Ratio Split
-----------------------------------------------
.. automodule:: cornac.eval_methods.ratio_split
   :members:

Stratified Split
----------------------------------------------------
.. automodule:: cornac.eval_methods.stratified_split
   :members:
  
Cross Validation
----------------------------------------------------
.. automodule:: cornac.eval_methods.cross_validation
   :members: